@@ -192,7 +192,7 @@ OC.L10N.register(
     "Call in progress" : "Llamada en cursu",
     "You were mentioned" : "Mentáronte",
     "Write to conversation" : "Escribi na conversación",
-    "You were invited to a conversation." : "Convidáronte a una conversación.",
+    "Description" : "Descripción",
     "Private conversation" : "Conversación privada",
     "Failed to upload call recording" : "Nun se pue xubir la grabación de la llamada",
     "Dismiss notification" : "Escargar l'avisu",
@@ -200,6 +200,8 @@ OC.L10N.register(
     "Failed to transcript call recording" : "Nun se pue trescribir la grabación de la llamada",
     "Accept" : "Aceptar",
     "Decline" : "Refugar",
+    "New message" : "Mensaxe nuevu",
+    "Notification" : "Avisu",
     "{user} reacted with {reaction}" : "{user} reaicionó con «{reaction}»",
     "{user} reacted with {reaction} in {call}" : "{user} reaicionó con «{reaction}» en: {call}",
     "{user} sent you a private message" : "{user} unvióte un mensaxe priváu",
@@ -483,7 +485,6 @@ OC.L10N.register(
     "Bots settings" : "Configuración de los robós",
     "State" : "Estáu",
     "Name" : "Nome",
-    "Description" : "Descripción",
     "Total errors count" : "Númberu d'errores totales",
     "Find more bots" : "Atopar más robós",
     "Beta" : "Beta",
@@ -509,6 +510,7 @@ OC.L10N.register(
     "Delete this server" : "Desaniciar esti sirvidor",
     "Test this server" : "Probar esti sirvidor",
     "SIP configuration saved!" : "¡Guardóse la configuración de SIP!",
+    "Error code" : "Códigu d'error",
     "High-performance backend URL" : "URL del backend de rindimientu altu",
     "High-performance backend settings saved" : "Guardóse la configuración del backend de rindimientu altu",
     "STUN server URL" : "URL del sirvidor STUN",
@@ -532,7 +534,6 @@ OC.L10N.register(
     "Cancel" : "Encaboxar",
     "Now" : "Agora",
     "Loading …" : "Cargando…",
-    "No upcoming events" : "Nun hai eventos próximos",
     "From" : "De",
     "To" : "Pa",
     "Calendar" : "Calendariu",
@@ -540,6 +541,8 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Nun hai nengún resultáu",
     "Done" : "Fecho",
+    "Raise hand" : "Alzar la mano",
+    "Lower hand" : "Baxar la mano",
     "This conversation is read-only" : "Esta conversación ye namás de llectura",
     "{nickName} raised their hand." : "«{nickName}» alzo la mano",
     "A participant raised their hand." : "Un participante alzó la mano.",
@@ -548,6 +551,7 @@ OC.L10N.register(
     "Connecting …" : "Conectando…",
     "Calling …" : "Llamando…",
     "Copy link" : "Copiar l'enllaz",
+    "None" : "Nada",
     "Error while accessing camera" : "Hebo un error mentanto s'accedía a la cámara",
     "You are not allowed to enable video" : "Nun tienes permisu p'activar el videu",
     "No video. Click to select device" : "Nun hai videu. Calca pa seleicionar un preséu",
@@ -626,7 +630,10 @@ OC.L10N.register(
     "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
     "Log content" : "Conteníu del rexistru",
     "Notifications" : "Avisos",
+    "Important conversation" : "Converación importante",
+    "Join" : "Xunise",
     "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
+    "Unread mentions" : "Menciones ensin lleer",
     "Create conversation" : "Crear una conversación",
     "Log in" : "Aniciar la sesión",
     "An error occurred while calling a phone number" : "Prodúxose un error mentanto se llamaba a un númberu de teléfonu",
@@ -646,8 +653,8 @@ OC.L10N.register(
     "You have no unread messages." : "Nun tienes nengún mensaxe ensin lleer.",
     "An error occurred while performing the search" : "Prodúxose un error mentanto se facía la busca",
     "Conversation list" : "Llista de conversaciones",
+    "Unread messages" : "Mensaxes ensin lleer",
     "New personal note" : "Nota personal nueva",
-    "Unread mentions" : "Menciones ensin lleer",
     "Talk settings" : "Configuración de Talk",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
@@ -662,14 +669,16 @@ OC.L10N.register(
     "Groups and teams" : "Grupos y equipos",
     "Other sources" : "Otros oríxenes",
     "You are currently waiting in the lobby" : "Tas na sala d'espera",
-    "None" : "Nada",
     "No microphone available" : "Nun hai nengún micrófonu disponible",
     "No camera available" : "Nun hai nenguna cámara disponible",
     "Devices" : "Preseos",
     "Backgrounds" : "Fondos",
-    "Media settings" : "Configuración multimedia",
+    "Calls are not supported in your browser" : "Les llamaes nun son compatible col sirvidor",
+    "Access to microphone is only possible with HTTPS" : "L'accesu al micrófonu namás ye posible con HTTPS",
+    "Access to microphone was denied" : "Negóse l'accesu al micrófonu",
+    "Error while accessing microphone" : "Hebo un error mentanto s'accedía al micrófonu",
+    "Access to camera is only possible with HTTPS" : "L'accesu a la cámara namás ye posible con HTTPS",
     "The call is being recorded." : "La llamada ta grabándose",
-    "Normal call" : "Llamada normal",
     "Invalid path selected" : "Seleicionóse un camín inválidu",
     "Blur" : "Emborrinar",
     "Upload" : "Xunir",
@@ -677,7 +686,6 @@ OC.L10N.register(
     "Message sent" : "Unvióse'l mensaxe",
     "Deleting message" : "Desaniciando'l mensaxe",
     "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
-    "Unread messages" : "Mensaxes ensin lleer",
     "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
@@ -766,7 +774,6 @@ OC.L10N.register(
     "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
     "Show list of participants" : "Amosar la llista de participantes",
     "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
-    "Join" : "Xunise",
     "Back to main room" : "Volver a la sala principal",
     "Message all rooms" : "Xestionar toles sales",
     "Start session" : "Aniciar la sesión",
@@ -813,12 +820,8 @@ OC.L10N.register(
     "No open conversations found" : "Nun s'atopó nenguna conversación abierta",
     "Number is not valid" : "El númberu nun ye válidu",
     "Phone numbers" : "Númberos de teléfonu",
+    "Display name: {name}" : "Nome visible: {name}",
     "Save name" : "Guardar el nome",
-    "Calls are not supported in your browser" : "Les llamaes nun son compatible col sirvidor",
-    "Access to microphone is only possible with HTTPS" : "L'accesu al micrófonu namás ye posible con HTTPS",
-    "Access to microphone was denied" : "Negóse l'accesu al micrófonu",
-    "Error while accessing microphone" : "Hebo un error mentanto s'accedía al micrófonu",
-    "Access to camera is only possible with HTTPS" : "L'accesu a la cámara namás ye posible con HTTPS",
     "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
     "Sounds setting saved" : "Guardóse la configuración de los soníos",
     "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
@@ -830,10 +833,12 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atayos del tecláu",
     "Search" : "Buscar",
     "Space bar" : "Barra d'espaciu",
+    "More actions" : "Más aiciones",
     "Start call" : "Aniciar la llamada",
     "End call" : "Finar la llamada",
     "Stop recording" : "Parar la grabación",
     "Send a reaction" : "Unviar una reaición",
+    "Default" : "Por defeutu",
     "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
     "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
     "Screensharing options" : "Opciones de la compartición de pantalla",
@@ -850,9 +855,8 @@ OC.L10N.register(
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete.",
     "Show your screen" : "Amosar la to pantalla",
     "Stop screensharing" : "Dexar de compartir la pantalla",
-    "Raise hand" : "Alzar la mano",
-    "Lower hand" : "Baxar la mano",
     "Start recording" : "Aniciar la grabación",
+    "Keep" : "Caltener",
     "Open dialpad" : "Abrir el tecláu numbéricu",
     "Submit" : "Unviar",
     "Search …" : "Buscar…",
@@ -861,7 +865,6 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "¡Xúnite una conversación o anicia una nueva!",
     "Duplicate session" : "Duplicar la sesión",
     "Join a conversation or start a new one" : "Xúnite a una conversación o anicia otra",
-    "Display name: {name}" : "Nome visible: {name}",
     "Nextcloud URL" : "URL de Nextcloud",
     "Nextcloud user" : "Usuariu de Nextcloud",
     "Talk conversation" : "Conversación de Talk",
@@ -908,6 +911,7 @@ OC.L10N.register(
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
     "You: {lastMessage}" : "Tu: {lastMessage}",
     "(edited)" : "(editóse)",
+    "Leave this page" : "Colar d'esta páxina",
     "In conversation" : "Na conversación",
     "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
     "Error occurred while allowing guests" : "Prodúxose un error mentanto se permitíen a los convidaos",
@@ -921,7 +925,6 @@ OC.L10N.register(
     "Could not post message: {errorMessage}" : "Nun se pudo espublizar el mensaxe: {errorMessage}",
     "Invitations sent" : "Unviáronse les invitaciones",
     "Error occurred when sending invitations" : "Prodúxose un error mentanto s'unviaben les conversaciones",
-    "Leave this page" : "Colar d'esta páxina",
     "An error occurred while requesting assistance" : "Prodúxose un error mentanto se solicitaba l'asistencia",
     "An error occurred while accepting an invitation" : "Prodúxose un error mentanto s'aceptaba una invitación",
     "An error occurred while submitting your vote" : "Prodúxose un error mentanto s'unviaba'l votu",
@@ -936,7 +939,6 @@ OC.L10N.register(
     "Please reload the page." : "Volvi cargar la páxina.",
     "Do not disturb" : "Nun molestar",
     "Away" : "Ausente",
-    "Default" : "Por defeutu",
     "Microphone {number}" : "Micrófonu {number}",
     "Camera {number}" : "Cámara {number}",
     "Access to microphone & camera was denied" : "Negóse l'accesu al micrófonu y a la cámara",
@@ -951,21 +953,13 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Reports" : "Informes",
     "Call summary" : "Resume de llamaes",
-    "The command does not exist" : "El comandu nun esiste",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Prodúxose un error mentanto s'executaba'l comandu. Pidi a l'alministración que compruebe los rexistros.",
     "You tried to call {user}" : "Tentesti de llamar a {user}",
+    "You were invited to a conversation." : "Convidáronte a una conversación.",
     "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
-    "Moderators" : "Moderadores",
-    "Commands" : "Comandos",
-    "Command" : "Comandu",
-    "Script" : "Script",
-    "The message could not be sent" : "Nun se pudo unviar el mensaxe",
     "Copy conversation link" : "Copiar l'enllaz de la conversación",
-    "Channel ID or name" : "ID o nome de la canal",
-    "Loading" : "Cargando",
+    "Media settings" : "Configuración multimedia",
+    "Normal call" : "Llamada normal",
     "Close" : "Zarrar",
-    "Private poll" : "Encuesta privada",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada.",
-    "TURN server" : "Sirividor TURN"
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
 },
 "nplurals=2; plural=(n != 1);");
