@@ -80,17 +80,16 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Talk mentions" : "Menciones en Talk",
     "No unread mentions" : "No hay menciones sin leer",
-    "%s invited you to a conversation." : "%s te invitó a una conversación",
-    "You were invited to a conversation." : "fuiste invitado a una conversación",
     "Conversation invitation" : "invitación a una conversación",
-    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
-    "Join »%s«" : "Unirse »%s«",
+    "Description" : "Descripción",
     "Password request: %s" : "Solicitud de Password: %s",
     "Private conversation" : "Conversación privada",
     "Deleted user (%s)" : "Usuario eliminado (%s)",
     "Dismiss notification" : "Descartar notificación",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
+    "New message" : "Mensaje nuevo",
+    "Reminder" : "Recordatorio",
     "{user} sent you a private message" : "{user} te envió un mensaje privado",
     "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
     "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
@@ -329,7 +328,6 @@ OC.L10N.register(
     "Disabled" : "Deshabilitado",
     "State" : "Estado",
     "Name" : "Nombre",
-    "Description" : "Descripción",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
     "@-mentions only" : "Solo menciones con @",
@@ -347,6 +345,7 @@ OC.L10N.register(
     "Created at" : "Creado en",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
+    "Error code" : "Código de error",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
@@ -359,7 +358,6 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Cancel" : "Cancelar",
     "Loading …" : "Cargando …",
-    "No upcoming events" : "No hay eventos próximos",
     "From" : "De",
     "To" : "Para",
     "Calendar" : "Calendario",
@@ -367,12 +365,15 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Sin resultados",
     "Done" : "Terminado",
+    "Exit full screen (F)" : "Salir de pantalla completa (F)",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -389,8 +390,8 @@ OC.L10N.register(
     "Choose" : "Seleccionar",
     "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
-    "Personal" : "Personal",
     "Meeting" : "Reunión",
+    "Personal" : "Personal",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
@@ -401,18 +402,17 @@ OC.L10N.register(
     "Delete" : "Eliminar",
     "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
+    "Unread mentions" : "Menciones sin leer",
     "Enter your name" : "Ingrese su nombre",
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
-    "Unread mentions" : "Menciones sin leer",
     "Users" : " Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
     "No search results" : "No hay resultados de búsqueda",
-    "None" : "Ninguno",
     "Select a device" : "Seleccionar un dispositivo",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
@@ -466,6 +466,8 @@ OC.L10N.register(
     "Performance" : "Desempeño",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -475,8 +477,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Exit full screen (F)" : "Salir de pantalla completa (F)",
-    "Grid view" : "Vista de cuadrícula",
+    "Keep" : "Mantener",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Talk conversation" : "Conversación de Talk",
@@ -499,7 +500,6 @@ OC.L10N.register(
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Ausente",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
@@ -514,21 +514,11 @@ OC.L10N.register(
     "Tasks" : "Tareas",
     "Notes" : "Notas",
     "Reports" : "Informes",
-    "There are currently no commands available." : "No hay comandos disponibles actualmente",
-    "The command does not exist" : "El comando no existe",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
+    "%s invited you to a conversation." : "%s te invitó a una conversación",
+    "You were invited to a conversation." : "fuiste invitado a una conversación",
+    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
+    "Join »%s«" : "Unirse »%s«",
     "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
-    "Command" : "Comando",
-    "Loading" : "Cargando",
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
+    "Close" : "Cerrar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
