@@ -19,8 +19,10 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
+    "Description" : "Descripción",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "New message" : "Mensaje nuevo",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
@@ -35,7 +37,6 @@ OC.L10N.register(
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
     "Name" : "Nombre",
-    "Description" : "Descripción",
     "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
     "Enable encryption" : "Habilitar encripción",
@@ -61,11 +62,13 @@ OC.L10N.register(
     "Attendees" : "Asistentes",
     "Save" : "Guardar",
     "No results" : "No hay resultados",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -87,7 +90,6 @@ OC.L10N.register(
     "Add to favorites" : "Agregar a tus favoritos",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
     "Files" : "Archivos",
@@ -113,6 +115,8 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -122,7 +126,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "User" : "Ususario",
     "Password" : "Contraseña",
@@ -135,7 +138,6 @@ OC.L10N.register(
     "Other" : "Otro",
     "Group" : "Grupo",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
@@ -147,11 +149,6 @@ OC.L10N.register(
     "__language_name__" : "Español (Peru)",
     "Tasks" : "Tareas",
     "Notes" : "Notas",
-    "Loading" : "Cargando",
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
+    "Close" : "Cerrar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
