@@ -12,13 +12,17 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Administration" : "Administración",
+    "System" : "Sistema",
     "Talk to %s" : "Hablar con %s",
     "File is too big" : "El archivo es demasiado grande.",
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
+    "Description" : "Descripción",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "New message" : "Mensaje nuevo",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
@@ -26,23 +30,23 @@ OC.L10N.register(
     "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
-    "Name" : "Nombre",
-    "Description" : "Descripción",
+    "Limit to groups" : "Limitar a grupos",
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
+    "Name" : "Nombre",
     "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
+    "Enable encryption" : "Habilitar encripción",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
-    "Pending" : "Pendiente",
-    "Error" : "Error",
-    "Blocked" : "Bloqueado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
@@ -50,15 +54,21 @@ OC.L10N.register(
     "TURN server protocols" : "Protocolos del servidor TURN",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
-    "Back" : "Atrás",
-    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Copy link" : "Copiar liga",
+    "Back" : "Atrás",
+    "Cancel" : "Cancelar",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "No hay resultados",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -71,18 +81,15 @@ OC.L10N.register(
     "Restricted" : "Restringido",
     "Personal" : "Personal",
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
-    "Login" : "Iniciar sesión",
+    "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
-    "Loading" : "Cargando",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
     "Files" : "Archivos",
@@ -93,17 +100,14 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
     "Create new poll" : "Crear nueva encuesta",
-    "Settings" : "Configuraciones ",
-    "Create poll" : "Crear encuesta",
     "Send" : "Enviar",
+    "Create poll" : "Crear encuesta",
+    "Settings" : "Configuraciones ",
     "moderator" : "moderador",
+    "Remove participant" : "Eliminar participante",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
-    "Remove participant" : "Eliminar participante",
-    "No results" : "No hay resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
@@ -111,8 +115,8 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -120,11 +124,13 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Grid view" : "Vista de cuadrícula",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Submit" : "Enviar",
     "User" : "Usuario",
     "Password" : "Contraseña",
     "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
     "Polls" : "Encuestas",
@@ -132,7 +138,7 @@ OC.L10N.register(
     "Audio" : "Audio",
     "Other" : "Otro",
     "Group" : "Grupo",
-    "Default" : "Predeterminado",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
@@ -141,9 +147,8 @@ OC.L10N.register(
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Circles" : "Círculos",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
+    "__language_name__" : "Español (Paraguay)",
+    "Tasks" : "Tareas",
+    "Close" : "Cerrar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
