@@ -162,11 +162,8 @@ OC.L10N.register(
     "You were mentioned" : "Spomenuti ste",
     "Write to conversation" : "Napiši u razgovor",
     "Writes event information into a conversation of your choice" : "Upisuje informacije o događaju u željeni razgovor",
-    "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
-    "You were invited to a conversation." : "Pozvani ste u razgovor.",
     "Conversation invitation" : "Poziv u razgovor",
-    "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
-    "Join »%s«" : "Pridruži se »%s«",
+    "Description" : "Opis",
     "You can also dial-in via phone with the following details" : "Također se možete povezati putem telefona sa sljedećim podacima",
     "Dial-in information" : "Podaci za povezivanje putem telefona",
     "Meeting ID" : "ID sastanka",
@@ -177,6 +174,8 @@ OC.L10N.register(
     "Dismiss notification" : "Zanemari obavijest",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
+    "New message" : "Nova poruka",
+    "Reminder" : "Podsjetnik",
     "{user} in {call}" : "{user} u {call}",
     "Deleted user in {call}" : "Izbrisan korisnik u {call}",
     "{guest} (guest) in {call}" : "{guest} (gost) u {call}",
@@ -389,7 +388,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Sveti Martin (francuski dio)",
     "Madagascar" : "Madagaskar",
     "Marshall Islands" : "Maršalovi Otoci",
-    "Macedonia, the former Yugoslav Republic of" : "Makedonija, bivša jugoslavenska republika",
+    "North Macedonia" : "Sjeverna Makedonija",
     "Mali" : "Mali",
     "Myanmar" : "Mjanmar",
     "Mongolia" : "Mongolija",
@@ -535,7 +534,6 @@ OC.L10N.register(
     "Disabled" : "Onemogućeno",
     "State" : "Stanje",
     "Name" : "Naziv",
-    "Description" : "Opis",
     "Beta" : "Beta",
     "Permissions" : "Dopuštenja",
     "All messages" : "Sve poruke",
@@ -613,7 +611,6 @@ OC.L10N.register(
     "Cancel" : "Odustani",
     "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
     "Loading …" : "Učitavanje…",
-    "No upcoming events" : "Nema nadolazećih događaja",
     "From" : "Od",
     "To" : "Do",
     "Calendar" : "Kalendar",
@@ -621,6 +618,12 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Search participants" : "Pretraži sudionike",
     "No results" : "Nema rezultata",
+    "Raise hand" : "Podigni ruku",
+    "Raise hand (R)" : "Podigni ruku (R)",
+    "Lower hand" : "Spusti ruku",
+    "Lower hand (R)" : "Spusti ruku (R)",
+    "Speaker view" : "Prikaz govornika",
+    "Grid view" : "Prikaz rešetke",
     "This conversation is read-only" : "Ovaj razgovor je samo za čitanje",
     "{nickName} raised their hand." : "{nickName} je podigao ruku.",
     "A participant raised their hand." : "Sudionik je podigao ruku.",
@@ -639,6 +642,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Isključi zvuk (M)",
     "Unmute audio" : "Uključi zvuk",
     "Unmute audio (M)" : "Uključi zvuk (M)",
+    "None" : "Nema",
     "Access to camera was denied" : "Pristup kameri je odbijen",
     "Error while accessing camera" : "Došlo je do pogreške pri pristupanju kameri",
     "You have been muted by a moderator" : "Utišao vas je moderator",
@@ -676,10 +680,9 @@ OC.L10N.register(
     "Restricted" : "Ograničeno",
     "Advanced permissions" : "Napredna dopuštenja",
     "Edit permissions" : "Uredi dopuštenja",
+    "Meeting" : "Sastanak",
     "Conversation settings" : "Postavke razgovora",
     "Personal" : "Osobno",
-    "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
-    "Meeting" : "Sastanak",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona opasnosti",
     "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
@@ -701,8 +704,6 @@ OC.L10N.register(
     "Save password" : "Spremi zaporku",
     "Resend invitations" : "Ponovno pošalji pozivnice",
     "Error occurred when opening or limiting the conversation" : "Došlo je do pogreške pri otvaranju ili ograničavanju razgovora",
-    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
-    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
     "Start time has been updated" : "Vrijeme početka je ažurirano",
     "Error occurred while updating start time" : "Došlo je do pogreške pri ažuriranju vremena početka",
     "Meeting start time" : "Vrijeme početka sastanka",
@@ -727,11 +728,14 @@ OC.L10N.register(
     "Log content" : "Sadržaj zapisa",
     "Notifications" : "Obavijesti",
     "Notify about calls in this conversation" : "Obavijesti o pozivima u ovom razgovoru",
+    "Important conversation" : "Važan razgovor",
     "SIP dial-in is now enabled" : "Povezivanje putem SIP-a je omogućeno",
     "SIP dial-in is now disabled" : "Povezivanje putem SIP-a je onemogućeno",
     "Error occurred when enabling SIP dial-in" : "Došlo je do pogreške pri omogućavanju povezivanja putem SIP-a",
     "Error occurred when disabling SIP dial-in" : "Došlo je do pogreške pri onemogućavanju povezivanja putem SIP-a",
+    "Join" : "Pridruži se",
     "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
+    "Unread mentions" : "Nepročitana spominjanja",
     "Create conversation" : "Stvori razgovor",
     "Enter your name" : "Unesite svoje ime",
     "Log in" : "Prijavite se",
@@ -745,8 +749,8 @@ OC.L10N.register(
     "No conversations found" : "Nije pronađen nijedan razgovor",
     "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
     "Conversation list" : "Popis razgovora",
+    "Unread messages" : "Nepročitane poruke",
     "Clear filter" : "Ukloni filtar",
-    "Unread mentions" : "Nepročitana spominjanja",
     "Talk settings" : "Postavke razgovora",
     "Users" : "Korisnici",
     "Groups" : "Grupe",
@@ -757,14 +761,19 @@ OC.L10N.register(
     "The meeting will start soon" : "Sastanak počinje uskoro",
     "This meeting is scheduled for {startTime}" : "Sastanak počinje u {startTime}",
     "You are currently waiting in the lobby" : "Trenutno čekate u predvorju",
-    "None" : "Nema",
     "Select microphone" : "Odaberi mikrofon",
     "No microphone available" : "Nema dostupnih mikrofona",
     "Select camera" : "Odaberi kameru",
     "No camera available" : "Nema dostupnih kamera",
+    "Test" : "Ispitivanje",
     "Devices" : "Uređaji",
     "No audio" : "Nema zvuka",
     "No camera" : "Nema kamere",
+    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
+    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
+    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
+    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
+    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
     "Invalid path selected" : "Odabran nevažeći put",
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
@@ -775,7 +784,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
     "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
     "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
-    "Unread messages" : "Nepročitane poruke",
     "Reply" : "Odgovori",
     "Reply privately" : "Odgovori privatno",
     "Copy message link" : "Kopiraj poveznicu poruke",
@@ -811,8 +819,8 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "Nije dopušteno objavljivanje poruka u ovom razgovoru",
     "Joining conversation …" : "Pridruživanje razgovoru...",
     "Send message" : "Pošalji poruku",
-    "Add emoji" : "Dodaj emoji",
     "File to share" : "Datoteka za dijeljenje",
+    "Add emoji" : "Dodaj emoji",
     "Share from Files" : "Dijeli iz datoteka",
     "Share files to the conversation" : "Dijeli datoteke u razgovor",
     "Create new poll" : "Stvori novu anketu",
@@ -838,7 +846,6 @@ OC.L10N.register(
     "Updating permissions" : "Ažuriranje dopuštenja",
     "Settings" : "Postavke",
     "Anonymous poll" : "Anonimna anketa",
-    "Join" : "Pridruži se",
     "Disable lobby" : "Onemogući predvorje",
     "Settings for participant \"{user}\"" : "Postavke sudionika „{user}”",
     "Participant \"{user}\"" : "Sudionik „{user}”",
@@ -882,24 +889,19 @@ OC.L10N.register(
     "No results found" : "Nema rezultata",
     "Load more results" : "Učitaj više rezultata",
     "Projects" : "Projekti",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
     "Search conversations or users" : "Pretraži razgovore ili korisnike",
     "Select conversation" : "Odaberi razgovor",
-    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
-    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
-    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
-    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
-    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
     "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
+    "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
     "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
     "Error while setting read status privacy" : "Pogreška pri postavljanju privatnosti statusa čitanja",
     "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
     "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
-    "Choose devices" : "Odaberi uređaje",
     "Attachments folder" : "Mapa s privicima",
-    "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Appearance" : "Izgled",
     "Privacy" : "Privatnost",
     "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
@@ -917,11 +919,11 @@ OC.L10N.register(
     "Space bar" : "Razmaknica",
     "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Raise or lower hand" : "Podigni ili spusti ruku",
+    "More actions" : "Dodatne radnje",
     "Start call" : "Uputi poziv",
     "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
     "Recording" : "Snimanje",
-    "Disable background blur" : "Onemogući zamućenje pozadine",
-    "Blur background" : "Zamuti pozadinu",
+    "Default" : "Zadano",
     "You are not allowed to enable screensharing" : "Nije vam dopušteno omogućiti dijeljenje zaslona",
     "No screensharing" : "Nema dijeljenja zaslona",
     "Screensharing options" : "Mogućnosti dijeljenja zaslona",
@@ -933,6 +935,7 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Nekvalitetan audiozapis i prikaz.",
     "Bad sent audio and video quality." : "Nekvalitetan audiozapis i videozapis.",
     "Bad sent audio quality." : "Nekvalitetan audiozapis.",
+    "Disable background blur" : "Onemogući zamućenje pozadine",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti.",
@@ -952,12 +955,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Došlo je do pogreške pri pokretanju dijeljenja zaslona.",
     "Show your screen" : "Pokaži svoj zaslon",
     "Stop screensharing" : "Prekini dijeljenje zaslona",
-    "Speaker view" : "Prikaz govornika",
-    "Grid view" : "Prikaz rešetke",
-    "Raise hand" : "Podigni ruku",
-    "Raise hand (R)" : "Podigni ruku (R)",
-    "Lower hand" : "Spusti ruku",
-    "Lower hand (R)" : "Spusti ruku (R)",
     "Mute others" : "Utišaj druge",
     "Select a region" : "Odaberite regiju",
     "Submit" : "Šalji",
@@ -1019,10 +1016,16 @@ OC.L10N.register(
     "Show all files" : "Prikaži sve datoteke",
     "Group" : "Grupa",
     "You: {lastMessage}" : "Vi: {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
+    "Leave this page" : "Napusti ovu stranicu",
+    "Join here" : "Pridruži se ovdje",
+    "Post to a conversation" : "Objavite u razgovoru",
+    "Post to conversation" : "Objavi u razgovoru",
     "Error while clearing conversation history" : "Pogreška pri brisanju povijesti razgovora",
     "Error occurred while allowing guests" : "Došlo je do pogreške pri omogućavanju pristupa gostima",
     "Error occurred while disallowing guests" : "Došlo je do pogreške pri onemogućavanju pristupa gostima",
+    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
+    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
     "Conversation password has been saved" : "Zaporka razgovora je spremljena",
     "Conversation password has been removed" : "Zaporka razgovora je uklonjena",
     "Error occurred while saving conversation password" : "Došlo je do pogreške pri spremanju zaporke razgovora",
@@ -1034,9 +1037,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Nije moguće poslati pozivnicu za {actorId}",
     "Invitations sent" : "Pozivnice su poslane",
     "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
-    "Leave this page" : "Napusti ovu stranicu",
-    "Join here" : "Pridruži se ovdje",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
     "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
@@ -1045,7 +1045,6 @@ OC.L10N.register(
     "Please reload the page." : "Ponovno učitajte stranicu.",
     "Do not disturb" : "Ne ometaj",
     "Away" : "Odsutan",
-    "Default" : "Zadano",
     "Microphone {number}" : "Mikrofon {number}",
     "Camera {number}" : "Kamera {number}",
     "Speaker {number}" : "Zvučnik {number}",
@@ -1066,44 +1065,22 @@ OC.L10N.register(
     "__language_name__" : "Hrvatski",
     "Tasks" : "Zadaci",
     "Notes" : "Bilješke",
-    "There are currently no commands available." : "Trenutno nema dostupnih naredbi.",
-    "The command does not exist" : "Naredba ne postoji",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Došlo je do pogreške pri izvršenju naredbe. Zatražite od administratora da provjeri zapise.",
     "You tried to call {user}" : "Pokušali ste nazvati {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Poziv s %n gostom (trajanje {duration})","Poziv s %n gostiju (trajanje {duration})","Poziv s %n gostiju (trajanje {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Poziv u kojem sudjeluju {user1} i {user2} (trajanje {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2} i {user3} (trajanje {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2}, {user3} i {user4} (trajanje {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2}, {user3}, {user4} i {user5} (trajanje {duration})",
+    "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
+    "You were invited to a conversation." : "Pozvani ste u razgovor.",
+    "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
+    "Join »%s«" : "Pridruži se »%s«",
     "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Naredbe su nova beta značajka aplikacije Nextcloud Talk. Omogućuju vam pokretanje skripti na vašem Nextcloudovom poslužitelju. Možete ih definirati s pomoću sučelja naredbenog retka. Primjer skripte kalkulatora možete pronaći u našoj {linkstart}dokumentaciji{linkend}.",
-    "Moderators" : "Moderatori",
-    "Commands" : "Naredbe",
-    "Command" : "Naredba",
-    "Script" : "Skripta",
-    "Response to" : "Odgovor na",
-    "Enabled for" : "Omogućeno za",
-    "Hosted high-performance backend" : "Visokoučinkovit pozadinski sustav na poslužitelju",
-    "SIP configuration is only possible with a high-performance backend." : "Konfiguracija SIP-a može se uspostaviti samo uz visokoučinkovit pozadinski sustav.",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Vanjski signalni poslužitelj treba se upotrebljavati u većim instancama. Ostavite prazno ako želite upotrebljavati interni signalni poslužitelj.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Preporučujemo da postavite distribuiranu predmemoriju za Nextcloud Talk zajedno s učinkovitim pozadinskim sustavom.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Ne upozoravaj na poteškoće s povezivanjem u pozivima s više od 4 sudionika",
+    "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
     "Copy conversation link" : "Kopiraj poveznicu za razgovor",
-    "Channel ID or name" : "ID ili naziv kanala",
-    "Loading" : "Učitavanje",
     "Close" : "Zatvori",
-    "Password protect" : "Zaštita zaporkom",
+    "Choose devices" : "Odaberi uređaje",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
+    "Blur background" : "Zamuti pozadinu",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
-    "Post to conversation" : "Objavi u razgovoru",
     "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
     "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud je u načinu održavanja, ponovno učitajte stranicu",
-    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu.",
-    "Specify commands the users can use in chats" : "Navedite naredbe koje korisnici mogu koristiti pri razmjeni poruka",
-    "TURN server" : "Poslužitelj TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Poslužitelj TURN upotrebljava se za usmjeravanje prometa sudionika iza vatrozida.",
-    "Signaling servers" : "Signalni poslužitelji",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Vanjski signalni poslužitelj može se upotrebljavati u većim instancama. Ostavite prazno ako želite upotrebljavati interni signalizacijski poslužitelj."
+    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
