@@ -406,6 +406,7 @@ OC.L10N.register(
     "Save" : "Vista",
     "No results" : "Engar niðurstöður",
     "Done" : "Lokið",
+    "Grid view" : "Reitasýn",
     "This conversation is read-only" : "This conversation is read-only",
     "Connecting …" : "Tengist ...",
     "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
@@ -414,6 +415,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
     "Copy link" : "Afrita tengil",
     "Mute audio" : "Þagga hljóð",
+    "None" : "Enginn",
     "You have been muted by a moderator" : "You have been muted by a moderator",
     "Disable video" : "Gera myndskeið óvirk",
     "Enable video" : "Virkja myndskeið",
@@ -463,8 +465,8 @@ OC.L10N.register(
     "No search results" : "Engar leitarniðurstöður",
     "New group conversation" : "Nýtt hópsamtal…",
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
-    "None" : "Enginn",
     "Select a device" : "Veldu tæki",
+    "Test" : "Prófun",
     "Devices" : "Tæki",
     "No audio" : "Ekkert hljóð",
     "Invalid path selected" : "Ógild slóð valin",
@@ -510,8 +512,8 @@ OC.L10N.register(
     "Add participants" : "Bæta við þátttakanda",
     "Enter password" : "Enter password",
     "Send message" : "Senda skilaboð",
-    "Add emoji" : "Bæta við tjáningartákni",
     "File to share" : "Skrá til að deila",
+    "Add emoji" : "Bæta við tjáningartákni",
     "Share from Files" : "Deila úr skrám",
     "Upload from device" : "Senda inn frá tæki",
     "Create new poll" : "Búa til nýja könnun",
@@ -547,7 +549,9 @@ OC.L10N.register(
     "Performance" : "Afköst",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
+    "More actions" : "Fleiri aðgerðir",
     "Start call" : "Hefja samtal",
+    "Default" : "Sjálfgefið",
     "Screensharing options" : "Valkostir skjádeilingar",
     "Enable screensharing" : "Virkja skjádeilingu",
     "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
@@ -557,7 +561,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
-    "Grid view" : "Reitasýn",
     "Keep" : "Halda",
     "Select a region" : "Veldu svæði",
     "Submit" : "Senda inn",
@@ -584,7 +587,6 @@ OC.L10N.register(
     "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
     "Do not disturb" : "Ónáðið ekki",
     "Away" : "Fjarverandi",
-    "Default" : "Sjálfgefið",
     "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
     "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
     "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
