@@ -19,8 +19,10 @@ OC.L10N.register(
     "Invalid file provided" : "არასწორი ფაილი",
     "Invalid image" : "არასწორი სურათი",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
+    "Description" : "აღწერილობა",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
+    "New message" : "ახალი წერილი",
     "Join call" : "შეუერთდით ზარს",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
     "Open settings" : "პარამეტრების გახსნა",
@@ -35,7 +37,6 @@ OC.L10N.register(
     "Enabled" : "მოქმედია",
     "Disabled" : "არაა მოქმედი",
     "Name" : "სახელი",
-    "Description" : "აღწერილობა",
     "Permissions" : "უფლებები",
     "General settings" : "მთავარი პარამეტრები",
     "Enable encryption" : "შიფრაციის ამოქმედება",
@@ -63,11 +64,13 @@ OC.L10N.register(
     "Save" : "შენახვა",
     "No results" : "შედეგები არაა",
     "Done" : "დასრულდა",
+    "Grid view" : "ბადისებური ხედი",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Copy link" : "ბმულის კოპირება",
     "Mute audio" : "ხმის ჩახშობა",
+    "None" : "არც ერთი",
     "Disable video" : "ვიდეოს გათიშვა",
     "Enable video" : "ვიდეოს ამოქმედება",
     "You" : "თქვენ",
@@ -93,7 +96,6 @@ OC.L10N.register(
     "Add to favorites" : "რჩეულებში დამატება",
     "Users" : "მომხმარებლები",
     "Groups" : "ჯგუფები",
-    "None" : "არც ერთი",
     "Devices" : "მოწყობილობები",
     "Upload" : "ატვირთვა",
     "Files" : "ფაილები",
@@ -121,6 +123,8 @@ OC.L10N.register(
     "Privacy" : "კონფიდენციალურობა",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
+    "More actions" : "მეტი ქმედება",
+    "Default" : "საწყისი",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
@@ -130,7 +134,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
-    "Grid view" : "ბადისებური ხედი",
     "Submit" : "გაგზავნა",
     "User" : "მომხმარებელი",
     "Password" : "პაროლი",
@@ -143,7 +146,6 @@ OC.L10N.register(
     "Other" : "სხვა",
     "Group" : "ჯგუფი",
     "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
-    "Default" : "საწყისი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
     "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
@@ -155,11 +157,6 @@ OC.L10N.register(
     "__language_name__" : "ქართული",
     "Tasks" : "დავალებები",
     "Notes" : "ჩანაწერები",
-    "Loading" : "იტვირთება",
-    "Close" : "დახურვა",
-    "Password protect" : "პაროლით დაცვა",
-    "TURN server" : "TURN სერვერი",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი."
+    "Close" : "დახურვა"
 },
 "nplurals=2; plural=(n!=1);");
