@@ -609,6 +609,12 @@ OC.L10N.register(
     "Save" : "Sarva",
     "Search participants" : "Chirca partetzipantes",
     "No results" : "Perunu resurtadu",
+    "Raise hand" : "Àrtzia sa manu ",
+    "Raise hand (R)" : "Àrtzia sa manu (R)",
+    "Lower hand" : "Bàscia sa manu ",
+    "Lower hand (R)" : "Bàscia sa manu (R)",
+    "Speaker view" : "Bista de sa persone chi faeddat",
+    "Grid view" : "Bisione grìllia",
     "This conversation is read-only" : "Custa resonada est de letura sola",
     "{nickName} raised their hand." : "{nickName} ant artziadu sa manu",
     "A participant raised their hand." : "Una persona at artziadu sa manu",
@@ -627,6 +633,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Istuda s'àudiu (M)",
     "Unmute audio" : "Allue s'àudiu ",
     "Unmute audio (M)" : "Allue s'àudiu (M)",
+    "None" : "Perunu",
     "Access to camera was denied" : "S'atzessu a sa càmera est istadu negadu",
     "Error while accessing camera" : "Errore in s'atzessu a sa càmera",
     "You have been muted by a moderator" : "Una persona chi moderat ti nd'at tiradu s'àudiu",
@@ -743,15 +750,19 @@ OC.L10N.register(
     "Other sources" : "Àteras fontes",
     "New group conversation" : "Resonada de grupu noa",
     "You are currently waiting in the lobby" : "Immoe ses abetende in s'intrada",
-    "None" : "Perunu",
     "Select microphone" : "Seletziona su micròfonu",
     "No microphone available" : "Perunu micròfonu a disponimentu",
     "Select camera" : "Seletziona sa fotocàmera",
     "No camera available" : "Peruna fotocàmera a disponimentu",
+    "Test" : "Proa",
     "Devices" : "Dispositivos",
     "No audio" : "Àudiu perunu",
     "No camera" : "Peruna fotocàmera",
-    "Media settings" : "Cunfiguratzione de is elementos multimediales",
+    "Calls are not supported in your browser" : "Is mutidas no sunt suportadas in su navigadore tuo",
+    "Access to microphone is only possible with HTTPS" : "S'atzessu a su micròfonu si podet fàghere isceti cun HTTPS",
+    "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
+    "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
+    "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
     "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload" : "Càrriga",
     "Files" : "Archìvios",
@@ -805,8 +816,8 @@ OC.L10N.register(
     "Send message" : "Imbia messàgiu",
     "The participant will not be notified about new messages" : "Su partetzipante no ant a retzire notìficas de is messàgios noos",
     "Participants will not be notified about new messages" : "Is partetzipantes no ant a retzire notìficas de is messàgios noos",
-    "Add emoji" : "Agiunghe carighedda",
     "File to share" : "Archìviu de cumpartzire",
+    "Add emoji" : "Agiunghe carighedda",
     "Share from Files" : "Cumpartzi dae Archìvios",
     "Share files to the conversation" : "Cumpartzi archìvios in sa resonada",
     "Upload from device" : "Càrriga dae su dispositivu",
@@ -863,24 +874,19 @@ OC.L10N.register(
     "No results found" : "Perunu resurtadu agatadu",
     "Load more results" : "Càrriga àteros resurtados",
     "Projects" : "Progetos",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "Link to a conversation" : "Collega a una resonada",
     "Search conversations or users" : "Chirca resonadas o utentes",
     "Select conversation" : "Seletziona resonada",
-    "Calls are not supported in your browser" : "Is mutidas no sunt suportadas in su navigadore tuo",
-    "Access to microphone is only possible with HTTPS" : "S'atzessu a su micròfonu si podet fàghere isceti cun HTTPS",
-    "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
-    "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
-    "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
     "Choose the folder in which attachments should be saved." : "Sèbera in cale cartella depent èssere sarvados is alligongiados.",
+    "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
     "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
     "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
     "Error while setting read status privacy" : "Errore in sa cunfiguratzione de sa riservadesa de s'istadu de letura",
     "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
     "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
     "Error while saving sounds setting" : "Errore sarvende sa cunfiguratzione de is sonos",
-    "Choose devices" : "Sèbera dispositivos",
     "Attachments folder" : "Cartella de alligongiados",
-    "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
     "Appearance" : "Aspetu",
     "Privacy" : "Riservadesa",
     "Share my read-status and show the read-status of others" : "Cumpartzi s'istadu de letura miu e mustra cussu de àtere",
@@ -898,9 +904,11 @@ OC.L10N.register(
     "Space bar" : "Istanca de logu",
     "Push to talk or push to mute" : "Ispinghe pro faeddare o ispinghe pro tirare s'àudio",
     "Raise or lower hand" : "Àrtzia o bàscia sa manu",
+    "More actions" : "Àteras atziones",
     "Start call" : "Cumintza mutida",
     "You will be able to join the call only after a moderator starts it." : "As a pòdere intrare in una mutida isceti a pustis chi una persone chi moderat dda cumintzet.",
     "Recording" : "Registratzione",
+    "Default" : "Predefinidu",
     "You are not allowed to enable screensharing" : "Non tenes su permissu de ativare sa cumpartzidura de s'ischermu",
     "No screensharing" : "Peruna cumpartzidura de ischermu",
     "Screensharing options" : "Sèberos de sa cumpartzidura de s'ischermu",
@@ -927,12 +935,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "B'at àpidu un'errore incarrerende sa cumpartzidura de s'ischermu.",
     "Show your screen" : "Mustra s'ischermu tuo",
     "Stop screensharing" : "Firma sa cumpartzidura de s'ischermu",
-    "Speaker view" : "Bista de sa persone chi faeddat",
-    "Grid view" : "Bisione grìllia",
-    "Raise hand" : "Àrtzia sa manu ",
-    "Raise hand (R)" : "Àrtzia sa manu (R)",
-    "Lower hand" : "Bàscia sa manu ",
-    "Lower hand (R)" : "Bàscia sa manu (R)",
     "Mute others" : "Tira s'àudio a àtere",
     "Keep" : "Mantene",
     "Select a region" : "Seletziona una regione",
@@ -995,10 +997,11 @@ OC.L10N.register(
     "Show all files" : "Mustra totu is documentos",
     "Group" : "Grupu",
     "You: {lastMessage}" : "Tue: {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
     "Leave this page" : "Lassa custa pàgina",
     "Join here" : "Intra inoghe",
+    "Post to a conversation" : "Pùblica in una resonada",
+    "Post to conversation" : "Pùblica in sa resonada",
     "Error while clearing conversation history" : "Errore limpiende s'istòria de sa resonada",
     "Error occurred while allowing guests" : "B'at àpidu un'errore autorizende is persones invitadas",
     "Error occurred while disallowing guests" : "B'at àpidu un'errore refudende is persones invitadas",
@@ -1023,7 +1026,6 @@ OC.L10N.register(
     "Please reload the page." : "Torra a carrigare sa pàgina.",
     "Do not disturb" : "No istorbes",
     "Away" : "Foras",
-    "Default" : "Predefinidu",
     "Microphone {number}" : "Micròfonu {number}",
     "Camera {number}" : "Fotocàmera {number}",
     "Speaker {number}" : "Altoparlante {number}",
@@ -1051,7 +1053,9 @@ OC.L10N.register(
     "Join »%s«" : "Intra in »%s«",
     "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
     "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
+    "Media settings" : "Cunfiguratzione de is elementos multimediales",
     "Close" : "Serra",
+    "Choose devices" : "Sèbera dispositivos",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud est istadu agiornadu, torra a carrigare sa pàgina",
     "An error happened when trying to share your file" : "B'at àpidu un'errore proende a cumpartzire s'archìviu",
